UniversalPadding class

A widget that adds padding to its child.

UniversalPadding is the UniversalUI version of Padding. It provides responsive padding with automatic calculation for desktop and mobile. Automatically adjusts padding based on breakpoint and supports center-aligned layouts.

Basic Usage

UniversalPadding(
  padding: const EdgeInsets.all(16),
  child: const Text("Content"),
);

子ウィジェットにパディングを追加するウィジェット。

UniversalPaddingPaddingUniversalUI版です。レスポンシブ対応でデスクトップ・モバイルで適切なパディングを自動計算。 ブレークポイントに応じてパディングを調整し、中央寄せレイアウトを実現します。

基本的な利用方法

UniversalPadding(
  padding: const EdgeInsets.all(16),
  child: const Text("コンテンツ"),
);
Inheritance

Constructors

UniversalPadding({required Widget child, Key? key, EdgeInsetsGeometry? padding, bool? enableResponsivePadding})
A widget that adds padding to its child.
const

Properties

child Widget
Child Widgets.
final
enableResponsivePadding bool?
Specify whether to enable responsive padding.
final
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
padding EdgeInsetsGeometry?
Defines where to place the widget with respect to its parent.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited