UniversalHeaderTile class
Tiles that can be used as headers for profiles, etc.
UniversalHeaderTile is a specialized tile widget designed for header sections in profiles and similar layouts. Supports title, subtitle, description, and actions with customizable styling and shimmer effect for loading states.
Basic Usage
UniversalHeaderTile(
title: const Text("User Name"),
subtitle: const Text("Subtitle"),
description: const Text("Description text"),
actions: [
IconButton(
icon: const Icon(Icons.settings),
onPressed: () {
// Handle settings action
},
),
],
);
プロフィールなどのヘッダーに用いることのできるタイル。
UniversalHeaderTileはプロフィールなどのヘッダーセクション用に設計された専用のタイルウィジェットです。 title、subtitle、description、actionsをサポートし、カスタマイズ可能なスタイリングと読み込み状態用のシマーエフェクトを提供します。
基本的な利用方法
UniversalHeaderTile(
title: const Text("ユーザー名"),
subtitle: const Text("サブタイトル"),
description: const Text("説明文"),
actions: [
IconButton(
icon: const Icon(Icons.settings),
onPressed: () {
// 設定アクションを処理
},
),
],
);
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- UniversalHeaderTile
Constructors
-
UniversalHeaderTile({required Widget title, Key? key, Widget? subtitle, Widget? description, TextStyle? titleTextStyle, TextStyle? subtitleTextStyle, TextStyle? descriptionTextStyle, List<
Widget> actions = const [], EdgeInsetsGeometry padding = const EdgeInsets.symmetric(horizontal: 16), EdgeInsetsGeometry contentPadding = const EdgeInsets.all(16), bool shimmer = false, Color? shimmerBaseColor, Color? shimmerHighlightColor, int shimmerDescriptionLineCount = 4}) -
Tiles that can be used as headers for profiles, etc.
const
Properties
-
actions
→ List<
Widget> -
Actions.
final
- contentPadding → EdgeInsetsGeometry
-
Content padding.
final
- description → Widget?
-
Description.
final
- descriptionTextStyle → TextStyle?
-
Style of the description.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- padding → EdgeInsetsGeometry
-
Padding.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- shimmer → bool
-
Specify
trueto use shimmer effect.final - shimmerBaseColor → Color?
-
Base color for shimmer effects.
final
- shimmerDescriptionLineCount → int
-
Shimmer description line count.
final
- shimmerHighlightColor → Color?
-
Highlight color when using shimmer effect.
final
- subtitle → Widget?
-
Subtitle.
final
- subtitleTextStyle → TextStyle?
-
Style of the subtitle.
final
- title → Widget
-
Title.
final
- titleTextStyle → TextStyle?
-
Style of the title.
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited